@@ -1,15 +1,11 @@
 // SPDX-License-Identifier: MIT
 
-// For subclass of [`FwFcp`][crate::FwFcp].
 mod fw_fcp;
 
-// For subclass of [`FwNode`][crate::FwNode].
 mod fw_node;
 
-// For subclass of [`FwReq`][crate::FwReq].
 mod fw_req;
 
-// For subclass of [`FwResp`][crate::FwResp].
 mod fw_resp;
 
 /// For convenience to provide traits and their blanket implementations to write subclass.
@@ -20,6 +16,5 @@ pub mod prelude {
 use {
     super::*,
     glib::{subclass::prelude::*, translate::*, Class},
-    libc::*,
     prelude::*,
 };
